# 🖱️ Bookshelf Interaction

This datapack allows you attach interaction events (click, hover) to interaction entities, enabling dynamic player interactions.

> “As far as the customer is concerned, the interface is the product.”
>
> -- Jef Raskin

For more details and usage examples, check out the Bookshelf [documentation](https://docs.mcbookshelf.dev/en/latest/modules/interaction.html).


## 📖 About Bookshelf

This module is part of the [Bookshelf Library](https://docs.mcbookshelf.dev/en/latest/index.html), a modular library datapack designed to simplify complex systems in Minecraft. Explore the full range of modules and discover how Bookshelf can simplify your Minecraft creations!
